class SSLDataPackageVariables:
    def __init__(self):
        self.SSLDataPackageIP = "0.0.0.0"
        self.SSLDataPackagePort = 8443
        self.SSLDataPackageStatus = ""